@@ -1,6 +1,12 @@
+import copy
 from ..model.snowflake import Snowflake
 
 
+class CopyableObject:
+    def copy(self):
+        return copy.copy(self)
+
+
 class EventBase:
     def __init__(self, client, resp: dict):
         self.raw = resp
