@@ -1,15 +1,14 @@
-import copy
 import inspect
 import typing
 import pathlib
 import datetime
 
 from .emoji import Emoji
-from .guild import Member
+from .guild import GuildMember
 from .permission import PermissionFlags, Role
 from .snowflake import Snowflake
 from .user import User
-from ..base.model import DiscordObjectBase, TypeBase, FlagBase
+from ..base.model import CopyableObject, DiscordObjectBase, TypeBase, FlagBase
 
 
 class Channel(DiscordObjectBase):
@@ -183,7 +182,7 @@ class Message(DiscordObjectBase):
         self.guild_id = Snowflake.optional(resp.get("guild_id") or guild_id)
         self.author = User.create(client, resp["author"])
         self.__member = resp.get("member")
-        self.member = Member.create(self.client, self.__member, user=self.author, guild_id=self.guild_id) if self.__member else self.__member
+        self.member = GuildMember.create(self.client, self.__member, user=self.author, guild_id=self.guild_id) if self.__member else self.__member
         self.content = resp["content"]
         self.timestamp = datetime.datetime.fromisoformat(resp["timestamp"])
         self.__edited_timestamp = resp["edited_timestamp"]
@@ -215,7 +214,7 @@ class Message(DiscordObjectBase):
         self.interaction = MessageInteraction(self.client, self.__interaction) if self.__interaction else self.__interaction
         self.__thread = resp.get("thread")
         self.thread = Channel.create(self.client, self.__thread, guild_id=self.guild_id) if self.__thread else self.__thread
-        self.components = [Component.auto_detect(client, x) for x in resp.get("components", [])]
+        self.components = [Component.auto_detect(x) for x in resp.get("components", [])]
 
     def reply(self, content=None, **kwargs):
         kwargs["message_reference"] = self
@@ -387,7 +386,7 @@ class Reaction:
         self.emoji = Emoji(client, resp["emoji"])
 
 
-class Overwrite:
+class Overwrite(CopyableObject):
     def __init__(self, resp):
         self.id = Snowflake(resp["id"])
         self.type = resp["type"]
@@ -452,7 +451,7 @@ class ThreadMember:
             return cls(client, resp)
 
 
-class Embed:
+class Embed(CopyableObject):
     def __init__(self, *, title: str = None, description: str = None, url: str = None, timestamp: datetime.datetime = None, color: int = None, **kwargs):
         resp = self.__create(title=title, description=description, url=url, timestamp=timestamp, color=color)
         resp.update(kwargs)
@@ -533,7 +532,7 @@ class Embed:
         return ret
 
 
-class EmbedThumbnail:
+class EmbedThumbnail(CopyableObject):
     def __init__(self, resp):
         self.url = resp.get("url")
         self.proxy_url = resp.get("proxy_url")
@@ -558,7 +557,7 @@ class EmbedThumbnail:
             return cls(resp)
 
 
-class EmbedVideo:
+class EmbedVideo(CopyableObject):
     def __init__(self, resp):
         self.url = resp.get("url")
         self.proxy_url = resp.get("proxy_url")
@@ -583,7 +582,7 @@ class EmbedVideo:
             return cls(resp)
 
 
-class EmbedImage:
+class EmbedImage(CopyableObject):
     def __init__(self, resp):
         self.url = resp.get("url")
         self.proxy_url = resp.get("proxy_url")
@@ -608,7 +607,7 @@ class EmbedImage:
             return cls(resp)
 
 
-class EmbedProvider:
+class EmbedProvider(CopyableObject):
     def __init__(self, resp):
         self.name = resp.get("name")
         self.url = resp.get("url")
@@ -627,7 +626,7 @@ class EmbedProvider:
             return cls(resp)
 
 
-class EmbedAuthor:
+class EmbedAuthor(CopyableObject):
     def __init__(self, resp):
         self.name = resp.get("name")
         self.url = resp.get("url")
@@ -652,7 +651,7 @@ class EmbedAuthor:
             return cls(resp)
 
 
-class EmbedFooter:
+class EmbedFooter(CopyableObject):
     def __init__(self, resp):
         self.text = resp["text"]
         self.icon_url = resp.get("icon_url")
@@ -672,7 +671,7 @@ class EmbedFooter:
             return cls(resp)
 
 
-class EmbedField:
+class EmbedField(CopyableObject):
     def __init__(self, resp):
         self.name = resp["name"]
         self.value = resp["value"]
@@ -740,7 +739,7 @@ class ChannelMention:
         self.name = resp["name"]
 
 
-class AllowedMentions:
+class AllowedMentions(CopyableObject):
     def __init__(self, *,
                  everyone: bool = False,
                  users: typing.List[typing.Union[str, int, Snowflake]] = None,
@@ -765,9 +764,6 @@ class AllowedMentions:
             ret["replied_user"] = self.replied_user
         return ret
 
-    def copy(self):
-        return copy.copy(self)
-
 
 class ListThreadsResponse:
     def __init__(self, client, resp):
